Welcome to CENdetectHOR library documentation!
===================================

The **CENdetectHOR library** offers functions to characterise tandem repeats in genomic sequences in terms of evolutionary relationships, looking for so called higher-order-repeats (HORs).
It has been specifically designed to analyse non-coding centromeric high-repetition regions of chromosomes. 

Check out the :doc:`usage` section for further information, including
how to :ref:`installation` the project.

.. note::

   This project is under active development.

Contents
--------

.. toctree::

   usage
   api
